.. _{{ fullname }}:


.. title:: {{ fullname }}

.. raw:: html

    <center>

**{{ fullname }}**

.. raw:: html

    <br>
    </center>

.. auto{{ objtype }}:: {{ fullname }}
    :members:
    :private-members:
    :undoc-members:

.. raw:: html

    <br><br>
